@@ -3,6 +3,7 @@ from .envelope import envelope_hilbert
 from .fft import positive_fft
 from .filter import (
     bandpass_filter,
+    bandpass_filter_ideal,
     bandstop_filter,
     hampel_filter,
     highpass_filter,
@@ -14,6 +15,7 @@ __all__ = [
     "lowpass_filter",
     "highpass_filter",
     "bandpass_filter",
+    "bandpass_filter_ideal",
     "bandstop_filter",
     "mnf",
     "mdf",
